==> HZDR-Multiphase-Addon-1.0.0.tar.gz: README.md <==
# Prerequistes

- OpenFOAM from [The OpenFOAM Foundation](https://openfoam.org)
- OpenFOAM-dev installation with specific commits for OpenFOAM-dev and ThirdParty-dev
- installation instruction will use OpenFOAM environment variables
    * WM_PROJECT_DIR: directory where OpenFOAM core code is installed
    * WM_PROJECT_USER_DIR: OpenFOAM user directory where user's code is installed
- read about installation of [OpenFOAM-dev from Source Repository](https://openfoam.org/download/source/)

# Installation of OpenFOAM-dev

## Installation of OpenFOAM-dev from official GitHub repository

- clone repository
    ```shell
    git clone https://github.com/OpenFOAM/OpenFOAM-dev.git
    git clone https://github.com/OpenFOAM/ThirdParty-dev.git
    ```
- checkout required commit
    ```
    cd OpenFOAM-dev
    git reset --hard 85f043040b169bf0510f4408066387d343c25502
    cd ..
    cd ThirdParty-dev
    git reset --hard c53f2dbf37177dec40a2056df9111608883da7c0
    cd ..
    ```
- follow installation instructions for [OpenFOAM Source Directory](https://openfoam.org/download/source/)

## Installation of OpenFOAM-dev and ThirdParty-dev provided with code publication

- download tar for OpenFOAM-dev and ThirdParty-dev
- unpack tar into installation directory for OpenFOAM
    ```shell
    tar -xzf OpenFOAM-dev.tar.gz
    tar -xzf ThirdParty-dev.tar.gz
    ```
- follow installation instructions for [OpenFOAM Source Directory](https://openfoam.org/download/source/)

# Installation of HZDR Multiphase Addon for OpenFOAM

- download tar archive for HZDR Multiphase Addon for OpenFOAM
- make sure your OpenFOAM environment is setup correctly, e.g. by running `foamVersion`
- unpack into OpenFOAM user directory and compile the addon
    ```shell
    tar -xzf HZDR_Multiphase_Addon-<version>.tar.gz $WM_PROJECT_USER_DIR
    cd $WM_PROJECT_USER_DIR
    ./Allwmake -j 4
    ```

==> HZDR-Multiphase-Addon-1.1.0.tar.gz: README.md <==
# Prerequistes

- OpenFOAM from [The OpenFOAM Foundation](https://openfoam.org)
- OpenFOAM-dev installation with specific commits for OpenFOAM-dev and ThirdParty-dev
- installation instruction will use OpenFOAM environment variables
    * WM_PROJECT_DIR: directory where OpenFOAM core code is installed
    * WM_PROJECT_USER_DIR: OpenFOAM user directory where user's code is installed
- read about installation of [OpenFOAM-dev from Source Repository](https://openfoam.org/download/source/)

# Installation of OpenFOAM-dev

## Installation of OpenFOAM-dev from official GitHub repository

- clone repository
    ```shell
    git clone https://github.com/OpenFOAM/OpenFOAM-dev.git
    git clone https://github.com/OpenFOAM/ThirdParty-dev.git
    ```
- checkout required commit
    ```
    cd OpenFOAM-dev
    git reset --hard 1e728ad7e301d6656158f6cbde706bea6c559344
    cd ..
    cd ThirdParty-dev
    git reset --hard c53f2dbf37177dec40a2056df9111608883da7c0
    cd ..
    ```
- follow installation instructions for [OpenFOAM Source Directory](https://openfoam.org/download/source/)

## Installation of OpenFOAM-dev and ThirdParty-dev provided with code publication

- download tar for OpenFOAM-dev and ThirdParty-dev
- unpack tar into installation directory for OpenFOAM
    ```shell
    tar -xzf OpenFOAM-dev.tar.gz
    tar -xzf ThirdParty-dev.tar.gz
    ```
- follow installation instructions for [OpenFOAM Source Directory](https://openfoam.org/download/source/)

# Installation of HZDR Multiphase Addon for OpenFOAM

- download tar archive for HZDR Multiphase Addon for OpenFOAM
- make sure your OpenFOAM environment is setup correctly, e.g. by running `foamVersion`
- unpack into OpenFOAM user directory and compile the addon
    ```shell
    mkdir -p $WM_PROJECT_USER_DIR
    tar -xzf HZDR_Multiphase_Addon-<version>.tar.gz -C $WM_PROJECT_USER_DIR
    cd $WM_PROJECT_USER_DIR
    ./Allwmake -j
    ```
